==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicButtonListener__241.h <==
// final class javax.swing.plaf.basic.BasicButtonListener$1

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class 8d26c0f91b647a39 javax_swing_plaf_basic_BasicButtonListener__241

// header file dependencies
// @dep_header javax_swing_AbstractAction

#include "javax/swing/AbstractAction.h"

#ifndef _JC_javax_swing_plaf_basic_BasicButtonListener__241_H_
#define _JC_javax_swing_plaf_basic_BasicButtonListener__241_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicButtonListener$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$sub_refs	_jc_javax_swing_plaf_basic_BasicButtonListener__241$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicButtonListener__241$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$refs	_jc_javax_swing_plaf_basic_BasicButtonListener__241$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$nonrefs	_jc_javax_swing_plaf_basic_BasicButtonListener__241$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$object	_jc_javax_swing_plaf_basic_BasicButtonListener__241$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$vmethods	_jc_javax_swing_plaf_basic_BasicButtonListener__241$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$vtable	_jc_javax_swing_plaf_basic_BasicButtonListener__241$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$vtype	_jc_javax_swing_plaf_basic_BasicButtonListener__241$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicButtonListener__241$method$_init$8cea2118e8666e8f(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$object *, struct _jc_javax_swing_plaf_basic_BasicButtonListener$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicButtonListener__241$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$object *, struct _jc_java_awt_event_ActionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicButtonListener__241$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$object *, struct _jc_java_awt_event_ActionEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_plaf_basic_BasicButtonListener__241$vmethods	javax_swing_plaf_basic_BasicButtonListener__241;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicButtonListener__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicButtonListener$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$refs {
    _jc_javax_swing_plaf_basic_BasicButtonListener__241$sub_refs	javax_swing_plaf_basic_BasicButtonListener__241;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_plaf_basic_BasicButtonListener__241$sub_nonrefs	javax_swing_plaf_basic_BasicButtonListener__241;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$object {
	_jc_javax_swing_plaf_basic_BasicButtonListener__241$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicButtonListener__241$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicButtonListener__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicButtonListener__241$vtype _jc_javax_swing_plaf_basic_BasicButtonListener__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicButtonListener__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicButtonListener__241$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicButtonListener__241_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicButtonListener__241.h <==
// final class javax.swing.plaf.basic.BasicButtonListener$1

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class 8d26c0f91b647a39 javax_swing_plaf_basic_BasicButtonListener__241

// header file dependencies
// @dep_header javax_swing_AbstractAction

#include "javax/swing/AbstractAction.h"

#ifndef _JC_javax_swing_plaf_basic_BasicButtonListener__241_H_
#define _JC_javax_swing_plaf_basic_BasicButtonListener__241_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicButtonListener$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$sub_refs	_jc_javax_swing_plaf_basic_BasicButtonListener__241$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicButtonListener__241$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$refs	_jc_javax_swing_plaf_basic_BasicButtonListener__241$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$nonrefs	_jc_javax_swing_plaf_basic_BasicButtonListener__241$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$object	_jc_javax_swing_plaf_basic_BasicButtonListener__241$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$vmethods	_jc_javax_swing_plaf_basic_BasicButtonListener__241$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$vtable	_jc_javax_swing_plaf_basic_BasicButtonListener__241$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$vtype	_jc_javax_swing_plaf_basic_BasicButtonListener__241$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicButtonListener__241$method$_init$8cea2118e8666e8f(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$object *, struct _jc_javax_swing_plaf_basic_BasicButtonListener$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicButtonListener__241$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicButtonListener__241$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_plaf_basic_BasicButtonListener__241$vmethods	javax_swing_plaf_basic_BasicButtonListener__241;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicButtonListener__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicButtonListener$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$refs {
    _jc_javax_swing_plaf_basic_BasicButtonListener__241$sub_refs	javax_swing_plaf_basic_BasicButtonListener__241;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_plaf_basic_BasicButtonListener__241$sub_nonrefs	javax_swing_plaf_basic_BasicButtonListener__241;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicButtonListener__241$object {
	_jc_javax_swing_plaf_basic_BasicButtonListener__241$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicButtonListener__241$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicButtonListener__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicButtonListener__241$vtype _jc_javax_swing_plaf_basic_BasicButtonListener__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicButtonListener__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicButtonListener__241$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicButtonListener__241_H_ */
